# repoproviders

|            |                                                                                                                                                                                                                                                                                                                                                                                                                              |
| ---------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| Package    | [![Latest PyPI Version](https://img.shields.io/pypi/v/repoproviders.svg)](https://pypi.org/project/repoproviders/) [![Supported Python Versions](https://img.shields.io/pypi/pyversions/repoproviders.svg)](https://pypi.org/project/repoproviders/) [![Documentation](https://readthedocs.org/projects/repoproviders/badge/?version=latest)](https://repoproviders.readthedocs.io/en/latest/?badge=latest)                  |
| Meta       | [![BSD-3-Clause](https://img.shields.io/pypi/l/repoproviders.svg)](LICENSE) [![Code of Conduct](https://img.shields.io/badge/Contributor%20Covenant-v2.0%20adopted-ff69b4.svg)](.github/CODE_OF_CONDUCT.md) [![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/) [![Code Style Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black) |
| Automation |                                                                                                                                                                                                                                                                                                                                                                                                                              |

_Detect, resolve and fetch repositories of content_

## Copyright

- Copyright © 2024 Yuvi Panda.
- Free software distributed under the [3-Clause BSD License](./LICENSE).
